.. :changelog:

History
-------

1.0.0 (2021-06-21)
++++++++++++++++++

* First release on PyPI.


1.0.3 (2021-12-08)
++++++++++++++++++

* Accommodate tenant architecture by checking for a SiteSettings model to see if previous_password_count has been set.
* Second release on PyPI.


1.0.4 (2022-02-08)
++++++++++++++++++

* Set django admin user fields to autocomplete, and change password fields to read only.
* Third release on PyPI.


1.0.5 (2022-08-31)
++++++++++++++++++

* Extend support of password history up to 24 passwords.
* Fourth release on PyPI.
